==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/GetNetworkInterfaceStatusPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkInterfaceStatusPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property networkDeviceName Name of the NetworkDevice.
 * @property networkInterfaceName Name of the NetworkInterface
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetNetworkInterfaceStatusPlainArgs(
    public val networkDeviceName: String,
    public val networkInterfaceName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkInterfaceStatusPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkInterfaceStatusPlainArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkInterfaceStatusPlainArgs.builder()
            .networkDeviceName(networkDeviceName.let({ args0 -> args0 }))
            .networkInterfaceName(networkInterfaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetNetworkInterfaceStatusPlainArgs].
 */
@PulumiTagMarker
public class GetNetworkInterfaceStatusPlainArgsBuilder internal constructor() {
    private var networkDeviceName: String? = null

    private var networkInterfaceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the NetworkDevice.
     */
    @JvmName("usqaagaxfbrmvpdw")
    public suspend fun networkDeviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkDeviceName = mapped
    }

    /**
     * @param value Name of the NetworkInterface
     */
    @JvmName("ccasrcpfirvhfnag")
    public suspend fun networkInterfaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkInterfaceName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("nsybwchulojgifjl")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetNetworkInterfaceStatusPlainArgs = GetNetworkInterfaceStatusPlainArgs(
        networkDeviceName = networkDeviceName ?: throw PulumiNullFieldException("networkDeviceName"),
        networkInterfaceName = networkInterfaceName ?: throw
            PulumiNullFieldException("networkInterfaceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/GetNetworkInterfaceStatusPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkInterfaceStatusPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property networkDeviceName Name of the NetworkDevice.
 * @property networkInterfaceName Name of the NetworkInterface
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetNetworkInterfaceStatusPlainArgs(
    public val networkDeviceName: String,
    public val networkInterfaceName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkInterfaceStatusPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkInterfaceStatusPlainArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.GetNetworkInterfaceStatusPlainArgs.builder()
            .networkDeviceName(networkDeviceName.let({ args0 -> args0 }))
            .networkInterfaceName(networkInterfaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetNetworkInterfaceStatusPlainArgs].
 */
@PulumiTagMarker
public class GetNetworkInterfaceStatusPlainArgsBuilder internal constructor() {
    private var networkDeviceName: String? = null

    private var networkInterfaceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the NetworkDevice.
     */
    @JvmName("sxxedioyuaneiapp")
    public suspend fun networkDeviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkDeviceName = mapped
    }

    /**
     * @param value Name of the NetworkInterface
     */
    @JvmName("dgqddqwdoyywgmvo")
    public suspend fun networkInterfaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkInterfaceName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("rdftjyobaiofjwyd")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetNetworkInterfaceStatusPlainArgs = GetNetworkInterfaceStatusPlainArgs(
        networkDeviceName = networkDeviceName ?: throw PulumiNullFieldException("networkDeviceName"),
        networkInterfaceName = networkInterfaceName ?: throw
            PulumiNullFieldException("networkInterfaceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
